summaryrefslogtreecommitdiff
path: root/include/value.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/value.h')
-rw-r--r--include/value.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/value.h b/include/value.h
index 336bb1d..b2ce89b 100644
--- a/include/value.h
+++ b/include/value.h
@@ -564,9 +564,9 @@ protected:
struct _zval_struct *_val;
/**
* The environment can access the zval directly
*/
- friend class Environment;
+ friend class Globals;
friend class Member;
};
@@ -564,9 +564,9 @@ protected:
struct _zval_struct *_val;
/**
- * The environment can access the zval directly
+ * The Globals and Member classes can access the zval directly
*/